import { BasicColumn, FormSchema } from '/@/components/Table';
import { optionsListApi } from '/@/api/tigerapi/wms/saleoutorder';
import { h, unref } from 'vue';
import { Tag, Tooltip } from 'ant-design-vue';
import { useI18n } from '/@/hooks/web/useI18n';
import { useLocale } from '/@/locales/useLocale';
// WMS.Saleoutorder
const { t: bt } = useI18n();
const { getLocale } = useLocale();

export const columns: BasicColumn[] = [
  {
    title: bt('单据代码'),
    resizable: true,
    sorter: true,
    dataIndex: 'BILLCODE',
    width: 200,
  },
  {
    title: bt('单据日期'),
    resizable: true,
    sorter: true,
    dataIndex: 'BILLDATE',
    width: 180,
  },
  {
    title: bt('操作时间'),
    resizable: true,
    sorter: true,
    dataIndex: 'CREATE_TIME',
    width: 180,
  },
  {
    title: bt('T100单据代码'),
    resizable: true,
    sorter: true,
    dataIndex: 'ERP_BILL_CODE',
    width: 180,
  },
  {
    title: bt('状态'),
    resizable: true,
    sorter: true,
    dataIndex: 'STATUS',
    width: 180,
    customRender: ({ record }) => {
      console.log('record', record);
      const status = record.STATUS;
      let text = '';
      let color = '';
      switch (status) {
        case 0:
          text = bt('新增');
          color = 'blue';
          break;
        case 1:
          text = bt('作业中');
          color = '#C2C247';
          break;
        case 2:
          text = bt('完成');
          color = 'green';
          break;
        default:
          break;
      }
      return h(Tag, { color: color }, () => text);
    },
  },

  {
    title: bt('仓库名称'),
    resizable: true,
    sorter: true,
    dataIndex: 'WAREHOUSECODE',
    width: 180,
  },
  {
    title: bt('创建人'),
    resizable: true,
    sorter: true,
    dataIndex: 'CREATE_USER',
    width: 180,
  },
  // {
  //   title: bt('创建时间'),
  //   resizable:true,
  //   width: 180,
  //   ifShow:true
  // },
];
//搜索
export const searchFormSchema: FormSchema[] = [
  {
    field: 'BILLCODE',
    label: bt('单据代码'),
    colProps: { span: 8 },
    component: 'Input',
  },
  {
    field: 'BILLDATE',
    label: bt('单据日期'),
    colProps: { span: 8 },
    component: 'RangePicker',
  },
  {
    field: 'STATUS',
    label: bt('状态'),
    component: 'ApiSelect',
    colProps: { span: 8 },
    componentProps: {
      api: optionsListApi,
      resultField: 'Data',
      labelField: unref(getLocale) == 'zh_CN' ? 'Desc' : 'Name',
      valueField: 'Value',
    },
  },
];

//销售出库单(WMS)明细
export const columns_D: BasicColumn[] = [
  {
    title: bt('序号'),
    resizable: true,
    sorter: true,
    dataIndex: 'BILLLINE',
    width: 200,
  },
  // {
  //   title: bt('单据代码'),
  //   resizable: true,
  //   sorter: true,
  //   dataIndex: 'BILLCODE',
  //   width: 200,
  // },
  {
    title: bt('物料名称'),
    resizable: true,
    sorter: true,
    dataIndex: 'ITEM_NAME',
    width: 200,
  },
  {
    title: bt('物料编码'),
    resizable: true,
    sorter: true,
    dataIndex: 'ITEM_CODE',
    width: 200,
  },
  {
    title: bt('操作时间'),
    resizable: true,
    sorter: true,
    dataIndex: 'CREATE_TIME',
    width: 180,
  },
  {
    title: bt('状态'),
    resizable: true,
    sorter: true,
    dataIndex: 'LINESTATUS',
    width: 180,
    customRender: ({ record }) => {
      console.log('record', record);
      const status = record.LINESTATUS;
      let text = '';
      let color = '';
      switch (status) {
        case 0:
          text = bt('新增');
          color = 'blue';
          break;
        case 1:
          text = bt('作业中');
          color = '#C2C247';
          break;
        case 2:
          text = bt('完成');
          color = '#C2C247';
          break;
        default:
          break;
      }
      return h(Tag, { color: color }, () => text);
    },
  },
  // {
  //   title: bt('出库仓库代码'),
  //   resizable:true,
  //   width: 200,
  // },
  // {
  //   title: bt('入库仓库代码'),
  //   resizable:true,
  //   width: 200,
  // },
  {
    title: bt('仓库名称'),
    resizable: true,
    sorter: true,
    dataIndex: 'WAREHOUSECODE',
    width: 200,
  },
  {
    title: bt('需求数量'),
    resizable: true,
    sorter: true,
    dataIndex: 'PRQTY',
    width: 100,
  },
  {
    title: bt('已发数量'),
    resizable: true,
    sorter: true,
    dataIndex: 'QTY',
    width: 100,
  },
  {
    title: bt('欠发数量'),
    resizable: true,
    sorter: true,
    dataIndex: 'OWE_QTY',
    width: 100,
  },
  // {
  //   title: bt('出库数量'),
  //   resizable:true,
  //   width: 200,
  // },
  // {
  //   title: bt('入库数量'),
  //   resizable:true,
  //   width: 200,
  // },
  // {
  //   title: bt('数量'),
  //   resizable:true,
  //   width: 200,
  // },
]

export const columns_S: BasicColumn[] = [
  {
    title: bt('条码'),
    resizable: true,
    sorter: true,
    dataIndex: 'SN',
    width: 200,
  },
  // {
  //   title: bt('创建时间'),
  //   resizable: true,
  //   sorter: true,
  //   dataIndex: 'CREATE_TIME',
  //   width: 180,
  // },
  {
    title: bt('修改时间'),
    resizable: true,
    sorter: true,
    dataIndex: 'UPDATE_TIME',
    width: 180,
  },
  {
    title: bt('状态'),
    resizable: true,
    sorter: true,
    dataIndex: 'STATUS',
    width: 180,
    customRender: ({ record }) => {
      console.log('record', record);
      const status = record.STATUS;
      let text = '';
      let color = '';
      switch (status) {
        case 0:
          text = bt('不存在');
          color = 'blue';
          break;
        case 10:
          text = bt('送货中');
          color = '#C2C247';
          break;
        case 20:
          text = bt('待检验');
          color = '#C2C247';
          break;
        case 30:
          text = bt('待入库');
          color = '#C2C247';
          break;
        case 40:
          text = bt('在库中');
          color = '#C2C247';
          break;
        case 50:
          text = bt('已下架');
          color = '#C2C247';
          break;
        case 60:
          text = bt('已发料');
          color = '#C2C247';
          break;
        case 70:
          text = bt('已上料');
          color = '#C2C247';
          break;
        case 80:
          text = bt('已耗尽');
          color = '#C2C247';
          break;
        case 90:
          text = bt('已退料');
          color = '#C2C247';
          break;
        case 100:
          text = bt('已发货');
          color = '#C2C247';
          break;
        default:
          break;
      }
      return h(Tag, { color: color }, () => text);
    },
  },
  {
    title: bt('物料编码'),
    resizable: true,
    sorter: true,
    dataIndex: 'ITEM_CODE',
    width: 200,
  },
  {
    title: bt('数量'),
    resizable: true,
    sorter: true,
    dataIndex: 'QTY',
    width: 200,
  },
];

export const searchFormSchema_D: FormSchema[] = [
  {
    field: 'ITEM_CODE',
    label: bt('物料编码'),
    colProps: { span: 8 },
    component: 'Input',
  },
  {
    field: 'LINESTATUS',
    label: bt('状态'),
    component: 'ApiSelect',
    colProps: { span: 8 },
    componentProps: {
      api: optionsListApi,
      resultField: 'Data',
      labelField: unref(getLocale) == 'zh_CN' ? 'Desc' : 'Name',
      valueField: 'Value',
    },
  }
];
export const searchFormSchema_S: FormSchema[] = [
  // {
  //   field: 'BILLCODE',
  //   label: bt('单据代码'),
  //   colProps: { span: 8 },
  //   component: 'Input',
  // },
  {
    field: 'ITEM_CODE',
    label: bt('物料编码'),
    colProps: { span: 8 },
    component: 'Input',
  },
  {
    field: 'SN',
    label: bt('条码'),
    colProps: { span: 8 },
    component: 'Input',
  },
  {
    field: 'STATUS',
    label: bt('状态'),
    component: 'ApiSelect',
    colProps: { span: 8 },
    componentProps: {
      api: optionsListApi,
      resultField: 'Data',
      labelField: unref(getLocale) == 'zh_CN' ? 'Desc' : 'Name',
      valueField: 'Value',
    },
  }
];


